import React, { useRef, useEffect, useState } from 'react';
import { Typography, Box } from '@material-ui/core';

import Header from '../../components/Header';
import Footer from '../../components/Footer';
import API from '../../core/Lti/api';
import Dialog from '../../components/Dialog';

import { Content, StyledContainer, Correta, Errada } from './styles';

export default function () {
  const headerref = useRef(Header)

  const [option, setOption] = useState(false)
  const [done, setDone] = useState(false)

  const key = 'question1-lux';
  const corretaA = (
    <>
      <Correta>
        Alternativa Correta A. Na luxação intrusiva, o dente estará deslocado
        axialmente em direção ao interior do alvéolo. O dente estará imóvel e à
        percussão apresentará um som metálico (dente travado no osso),
        semelhante aos casos de anquilose. Testes de sensibilidade pulpar
        apresentarão resultados negativos.
      </Correta>
    </>
  )
  const incorretaB = (
    <>
      <Errada>
        Alternativa Incorreta B. Na concussão, o dente é sensível à mastigação e
        à percussão e não apresentará deslocamento ou mobilidade. Em geral,
        respondem normalmente ao teste de sensibilidade pulpar térmico ou
        elétrico. Os achados radiográficos são ausentes.
      </Errada>
    </>
  )
  const incorretaC = (
    <>
      <Errada>
        Alternativa Incorreta C. Na subluxação, o dente apresentará
        sensibilidade à percussão e mobilidade aumentada, porém sem apresentar
        deslocamento. Geralmente, se observa sangramento do sulco gengival. Os
        testes de sensibilidade pulpar podem ser inicialmente negativos,
        indicando dano pulpar transitório, portanto é importante monitorar a
        resposta pulpar até que seja possível estabelecer um diagnóstico
        definitivo da condição pulpar.
      </Errada>
    </>
  )
  const incorretaD = (
    <>
      <Errada>
        Alternativa Incorreta D. Na luxação extrusiva, o dente estará deslocado
        para fora do alvéolo e apresentará excessiva mobilidade. Tanto o
        suprimento neurovascular da polpa, como o ligamento periodontal são
        rompidos. Os testes de sensibilidade pulpar apresentam normalmente
        resposta negativa.
      </Errada>
    </>
  )

  const [selecionada, setSelecionada] = useState()
  const [valor, setValor] = useState()

  useEffect(() => {
    const init = async () => {
      const data = await API.getData(key)
      if (data) {
        setOption(data.answer)
        setDone(true)
      }
      if (data != null) {
        if (data.answer === 'a') {
          setSelecionada([corretaA])
          console.log(selecionada)
        } else if (data.answer === 'b') {
          setSelecionada([incorretaB, corretaA])
        } else if (data.answer === 'c') {
          setSelecionada([incorretaC, corretaA])
        } else if (data.answer === 'd') {
          setSelecionada([incorretaD, corretaA])
        }
        setValor(data.answer)
      }
    }
    init()
  }, [])

  const selectOption = (e) => {
    if (e === 'a') {
      setSelecionada([corretaA])
      console.log(selecionada)
    } else if (e === 'b') {
      setSelecionada([incorretaB, corretaA])
    } else if (e === 'c') {
      setSelecionada([incorretaC, corretaA])
    } else if (e === 'd') {
      setSelecionada([incorretaD, corretaA])
    }
    setValor(e)
    setOption(e)
  };

  const sendAnswer = async () => {
    if (done) return true
    if (option === null) {
      return
    }
    console.log('opt: ', option)
    await API.setData(key, { answer: option })
    setDone(true)
  };

  return (
    <StyledContainer>
      <Header ref={headerref} />
      <Box className='container'>
        <Content Done={done}>
          <Box className='content'>
            <Box className='text'>
              <Typography variant='body1' className='indented'>
                Agora que você conheceu mais sobre traumas com luxações em
                dentes permanentes, teste seus conhecimentos sobre sua
                classificação, seu tratamento e prognóstico nas questões a
                seguir:
              </Typography>
            </Box>
            <Box className='question'>
              <Typography
                variant='body1'
                align='left'
                paragraph='true'
                className='titulo'
              >
                QUESTÃO 1
              </Typography>
              <Typography
                variant='body1'
                align='left'
                paragraph='true'
                className='objetivo'
              >
                <strong>Objetivo Educacional</strong>: Identificar as lesões de
                luxação em traumas de dentição permanente.
              </Typography>
              <Typography
                variant='body1'
                align='left'
                paragraph='true'
                className='enunciado'
              >
                <strong>
                  Um bom prognóstico do tratamento de traumatismos dentários
                  depende de um correto diagnóstico da condição do dente com um
                  tratamento rápido e acompanhamento. Em relação ao diagnóstico
                  das lesões de luxação é correto afirmar que:
                </strong>
              </Typography>
              <Typography variant='body1' align='left'>
                <p className='alternativas'>
                  <p onClick={done ? null : () => selectOption('a')} className={valor === 'a' ? 'alternativaMarcada' : 'alternativa'}>
                    Luxação intrusiva implica deslocamento em direção ao
                    interior do alvéolo.
                  </p>
                  <p onClick={done ? null : () => selectOption('b')} className={valor === 'b' ? 'alternativaMarcada' : 'alternativa'}>
                    Concussão possui mobilidade aumentada, com deslocamento e
                    sensibilidade à percussão.
                  </p>
                  <p onClick={done ? null : () => selectOption('c')} className={valor === 'c' ? 'alternativaMarcada' : 'alternativa'}>
                    Subluxação não possui mobilidade aumentada, sem deslocamento
                    e sensibilidade à percussão.
                  </p>
                  <p onClick={done ? null : () => selectOption('d')} className={valor === 'd' ? 'alternativaMarcada' : 'alternativa'}>
                    Luxação extrusiva implica deslocamento na direção apical
                    dentro do alvéolo.
                  </p>
                </p>
              </Typography>
              <Box className='enviar mt-2'>
                <Dialog
                  help
                  sendAnswer={sendAnswer}
                  content={selecionada}
                  title={
                    valor === 'a'
                      ? 'Questão 1 - Resposta Correta'
                      : 'Questão 1 - Resposta Errada'
                  }
                />
              </Box>
            </Box>
          </Box>
        </Content>
      </Box>
      <Footer prev='/p3' next='/p16' />
    </StyledContainer>
  )
}
