import React, { useRef, useEffect, useState } from "react";
import { Typography, Box } from "@material-ui/core";

import Header from "../../components/Header";
import Footer from "../../components/Footer";
import API from "../../core/Lti/api";
import Dialog from "../../components/Dialog";

import { Content, StyledContainer, Correta, Errada } from "./styles";

export default function () {
  const headerref = useRef(Header);

  const [option, setOption] = useState(false);
  const [done, setDone] = useState(false);

  const key = "question2-lux";
  const incorretaA = (
    <>
      <Errada>
        Alternativa Incorreta A. As características apresentadas são de
        subluxação. Em caso de mobilidade acentuada uma contenção flexível para
        estabilizar o elemento dentário e proporcionar conforto ao paciente pode
        ser indicada por até 2 semanas, pois o objetivo é formar células do
        ligamento periodontal.
      </Errada>
    </>
  );
  const incorretaB = (
    <>
      <Errada>
        Alternativa Incorreta B. Na concussão, o dente é sensível à mastigação e
        à percussão, porém não apresenta deslocamento ou mobilidade, portanto
        geralmente não requer o uso de contenção, apenas repouso mastigatório. A
        subluxação apresentada acima, em situações de mobilidade acentuada, pode
        ter indicação para o uso da contenção flexível.
      </Errada>
    </>
  );
  const corretaC = (
    <>
      <Correta>
        Alternativa Correta C. A subluxação é considerada o diagnóstico clínico
        provável do caso apresentado. Durante o tratamento desse dente, a
        contenção é um fator importante, porque estabiliza o dente e permite a
        cicatrização periodontal. A contenção deve ser colocada na superfície
        vestibular do dente para permitir a higiene bucal adequada.
      </Correta>
    </>
  );
  const incorretaD = (
    <>
      <Errada>
        Alternativa Incorreta D. Na concussão dentária, há uma força intensa e
        súbita sobre as estruturas dentárias e alveolares, mas não o suficiente
        para fraturar o dente ou o osso do processo alveolar. Na concussão
        dentária, a força se concentra em uma região muito pequena, lesando-a
        focalmente e o paciente geralmente apresenta sensibilidade, mas não há a
        mobilidade dental.
      </Errada>
    </>
  );

  const [selecionada, setSelecionada] = useState();
  const [valor, setValor] = useState();

  useEffect(() => {
    const init = async () => {
      const data = await API.getData(key);
      if (data) {
        setOption(data.answer);
        setDone(true);
      }
      if (data != null) {
        if (data.answer === "a") {
          setSelecionada([incorretaA, corretaC]);
          console.log(selecionada);
        } else if (data.answer === "b") {
          setSelecionada([incorretaB, corretaC]);
        } else if (data.answer === "c") {
          setSelecionada([corretaC]);
        } else if (data.answer === "d") {
          setSelecionada([incorretaD, corretaC]);
        }
        setValor(data.answer)
      }
    };
    init();
  }, []);

  const selectOption = (e) => {
    if (e === "a") {
      setSelecionada([incorretaA, corretaC]);
      console.log(selecionada);
    } else if (e === "b") {
      setSelecionada([incorretaB, corretaC]);
    } else if (e === "c") {
      setSelecionada([corretaC]);
    } else if (e === "d") {
      setSelecionada([incorretaD, corretaC]);
    }
    setValor(e);
    setOption(e);
  };

  const sendAnswer = async () => {
    if (done) return true;
    if (option === null) {
      return;
    }
    console.log("opt: ", option);
    await API.setData(key, { answer: option });
    setDone(true);
  };

  return (
    <StyledContainer>
      <Header ref={headerref} />
      <Box className='container'>
        <Content Done={done}>
          <Box className='content'>
            <Box className='question'>
              <Typography
                variant='body1'
                align='left'
                paragraph='true'
                className='titulo'
              >
                QUESTÃO 2
              </Typography>
              <Typography
                variant='body1'
                align='left'
                paragraph='true'
                className='objetivo'
              >
                <strong>Objetivo Educacional</strong>: Conhecer as condutas
                terapêuticas, diante das lesões de luxação.
              </Typography>
              <Typography
                variant='body1'
                align='left'
                paragraph='true'
                className='enunciado'
              >
                <strong>
                  Maria é uma criança de 8 anos de idade, que durante a aula de
                  Educação Física caiu no chão. De imediato, Maria relatou que o
                  “seu dente estava doendo”. Dona Josélia, mãe de Maria, foi
                  buscá-la na escola e a levou ao cirurgião-dentista. Após,
                  anamnese e exame físico o cirurgião-dentista identificou que o
                  elemento dental 11 apresentava mobilidade acentuada,
                  sensibilidade ao toque e sangramento do sulco gengival, porém
                  não havia o deslocamento do dente. Ao exame radiográfico, o
                  cirurgião-dentista observou que esse elemento dental
                  apresentava rizogênese incompleta. O diagnóstico e a conduta
                  de tratamento corretos, respectivamente são:
                </strong>
              </Typography>
              <Typography variant='body1' align='left' paragraph='true'>
                <p className='alternativas'>
                  <p onClick={done ? null : () => selectOption('a')} className={valor === 'a' ? 'alternativaMarcada' : 'alternativa'}>
                    Subluxação e contenção rígida.
                  </p>
                  <p onClick={done ? null : () => selectOption('b')} className={valor === 'b' ? 'alternativaMarcada' : 'alternativa'}>
                  Concussão e contenção rígida.
                  </p>
                  <p onClick={done ? null : () => selectOption('c')} className={valor === 'c' ? 'alternativaMarcada' : 'alternativa'}>
                  Subluxação e contenção flexível.
                  </p>
                  <p onClick={done ? null : () => selectOption('d')} className={valor === 'd' ? 'alternativaMarcada' : 'alternativa'}>
                  Concussão e contenção flexível.
                  </p>
                </p>
              </Typography>
              <Box className='enviar'>
                <Dialog
                  help
                  sendAnswer={sendAnswer}
                  content={selecionada}
                  title={
                    valor === "c"
                      ? "Questão 2 - Resposta Correta"
                      : "Questão 2 - Resposta Errada"
                  }
                />
              </Box>
            </Box>
          </Box>
        </Content>
      </Box>
      <Footer prev='/p15' />
    </StyledContainer>
  );
}
